@@ -23,6 +23,8 @@
 #include <math.h>
 #include <string.h>
 
+#include <memory>
+
 
 // We declare an auto pointer to ccdsim.
 std::auto_ptr<CCDSim> ccdsim(0);
@@ -153,7 +155,6 @@ bool CCDSim::Connect()
 {
 
     int nbuf;
-    SetupParms();
 
     if(HasGuideHead)
     {
@@ -230,6 +231,10 @@ bool CCDSim::updateProperties()
     IDDefNumber(SimulatorSettingsNV, NULL);
 
     INDI::CCD::updateProperties();
+
+    if (isConnected())
+        SetupParms();
+
     return true;
 }
 
