@@ -81,21 +81,21 @@ void ISNewSwitch(const char *dev, const char *name, ISState *states, char *names
 {
 	if(dev && strcmp (mydev, dev)) return;
 	ISInit();
-        tcfs->ISNewSwitch(name, states, names, num);
+        tcfs->ISNewSwitch(dev, name, states, names, num);
 }
 
 void ISNewText(	const char *dev, const char *name, char *texts[], char *names[], int num)
 {
 	if(dev && strcmp (mydev, dev)) return;
 	ISInit();
-        tcfs->ISNewText(name, texts, names, num);
+        tcfs->ISNewText(dev, name, texts, names, num);
 }
 
 void ISNewNumber(const char *dev, const char *name, double values[], char *names[], int num)
 {
 	if(dev && strcmp (mydev, dev)) return;
 	ISInit();
-        tcfs->ISNewNumber(name, values, names, num);
+        tcfs->ISNewNumber(dev, name, values, names, num);
 }
 
 void ISNewBLOB (const char *dev, const char *name, int sizes[], int blobsizes[], char *blobs[], char *formats[], char *names[], int n) 
@@ -238,8 +238,7 @@ bool TCFS::Connect()
 
     if (tty_connect(tProp->tp[0].text, 19200, 8, 0, 1, &fd) != TTY_OK)
     {
-        ConnectSP->s = IPS_ALERT;
-        IDSetSwitch (ConnectSP, "Error connecting to port %s. Make sure you have BOTH read and write permission to the port.", tProp->tp[0].text);
+        IDMessage(deviceName(), "Error connecting to port %s. Make sure you have BOTH read and write permission to the port.", tProp->tp[0].text);
 	return false;
     }
 
@@ -251,7 +250,7 @@ bool TCFS::Connect()
         {
             if (!strcmp(response, "!"))
             {
-                setConnected(true, IPS_OK, "Successfully connected to TCF-S Focuser in Manual Mode.");
+                IDMessage(deviceName(), "Successfully connected to TCF-S Focuser in Manual Mode.");
 
                 IUResetSwitch(FocusModeSP);
                 FocusModeSP->sp[0].s = ISS_ON;
@@ -274,7 +273,7 @@ bool TCFS::Connect()
         usleep(500000);
     }
 
-    setConnected(false, IPS_ALERT, "Error connecting to TCF-S focuser...");
+    IDMessage(deviceName(), "Error connecting to TCF-S focuser...");
     return false;
 
 }
@@ -305,7 +304,7 @@ bool TCFS::Disconnect()
 **
 **
 *****************************************************************/
-bool TCFS::ISNewNumber (const char *name, double values[], char *names[], int n)
+bool TCFS::ISNewNumber (const char *dev, const char *name, double values[], char *names[], int n)
 {
 
   INumberVectorProperty *nProp = getNumber(name);
@@ -316,7 +315,7 @@ bool TCFS::ISNewNumber (const char *name, double values[], char *names[], int n)
   if (isConnected() == false)
   {
       resetProperties();
-      IDMessage(deviceID, "TCF-S is offline. Connect before issiung any commands.");
+      IDMessage(deviceName(), "TCF-S is offline. Connect before issiung any commands.");
       return false;
   }
 
@@ -354,6 +353,8 @@ bool TCFS::ISNewNumber (const char *name, double values[], char *names[], int n)
       IDSetNumber(nProp, "Moving focuser to new position %g...", nFocusTargetPosition);
       return true;
   }
+
+  return DefaultDriver::ISNewNumber (dev, name, values, names, n);
     
 }
 
@@ -361,7 +362,7 @@ bool TCFS::ISNewNumber (const char *name, double values[], char *names[], int n)
 **
 **
 *****************************************************************/
-bool TCFS::ISNewText (const char *name, char *texts[], char *names[], int n)
+bool TCFS::ISNewText (const char *dev, const char *name, char *texts[], char *names[], int n)
 {
     ITextVectorProperty * tProp = getText(name);
 
@@ -381,7 +382,7 @@ bool TCFS::ISNewText (const char *name, char *texts[], char *names[], int n)
     }
 
 
-    return false;
+    return DefaultDriver::ISNewText(dev, name, texts, names, n);
 	
 }
 
@@ -389,12 +390,12 @@ bool TCFS::ISNewText (const char *name, char *texts[], char *names[], int n)
 **
 **
 *****************************************************************/
-bool TCFS::ISNewSwitch (const char *name, ISState *states, char *names[], int n)
+bool TCFS::ISNewSwitch (const char *dev, const char *name, ISState *states, char *names[], int n)
 {
 
     ISwitch *current_active_switch = NULL, *target_active_switch = NULL;
     // First process parent!
-    if (INDI::DefaultDriver::ISNewSwitch(deviceID, name, states, names, n) == true)
+    if (INDI::DefaultDriver::ISNewSwitch(deviceName(), name, states, names, n) == true)
         return true;
 
     ISwitchVectorProperty *sProp = getSwitch(name);
@@ -415,7 +416,7 @@ bool TCFS::ISNewSwitch (const char *name, ISState *states, char *names[], int n)
     if (isConnected() == false)
     {
       resetProperties();
-      IDMessage(deviceID, "TCF-S is offline. Connect before issiung any commands.");
+      IDMessage(deviceName(), "TCF-S is offline. Connect before issiung any commands.");
       return false;
     }
 
@@ -662,7 +663,7 @@ bool TCFS::ISNewSwitch (const char *name, ISState *states, char *names[], int n)
 
 
 
-    return false;
+    return DefaultDriver::ISNewSwitch(dev, name, states, names, n);
 }
 
 bool TCFS::move_focuser(TCFSMotion dir)
@@ -929,5 +930,5 @@ bool TCFS::read_tcfs()
 
 const char * TCFS::getDefaultName()
 {
-    return "TCFS";
+    return mydev;
 }
